==> ejc-print-api-3.0.0-20201023.013353-32-sources.jar: com/ejianc/foundation/print/vo/BusinessObjectVO.java <==
package com.ejianc.foundation.print.vo;

import com.ejianc.foundation.metadata.vo.MdClassVO;
import com.ejianc.foundation.metadata.vo.MdProjectVO;
import com.ejianc.framework.skeleton.template.BaseVO;

public class BusinessObjectVO extends BaseVO {

    private static final long serialVersionUID = -2040071706447007612L;
    /**
     * 业务对象编码
     */
    private String code;
    /**
     * 业务对象名称
     */
    private String name;
    /**
     *  业务对象内容
     */
    private String content;
    /**
     * 业务对象所属实体主键Id
     */
    private Long entityId;
    /**
     * 业务对象所属工程主键Id
     */
    private Long projectId;

    private MdProjectVO project;
    private MdClassVO entity;

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public Long getEntityId() {
        return entityId;
    }

    public void setEntityId(Long entityId) {
        this.entityId = entityId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public MdProjectVO getProject() {
        return project;
    }

    public void setProject(MdProjectVO project) {
        this.project = project;
    }

    public MdClassVO getEntity() {
        return entity;
    }

    public void setEntity(MdClassVO entity) {
        this.entity = entity;
    }
}

==> ejc-print-api-3.0.0-20201221.033701-50-sources.jar: com/ejianc/foundation/print/vo/BusinessObjectVO.java <==
package com.ejianc.foundation.print.vo;

import com.ejianc.foundation.metadata.vo.MdClassVO;
import com.ejianc.foundation.metadata.vo.MdProjectVO;
import com.ejianc.framework.skeleton.template.BaseVO;

public class BusinessObjectVO extends BaseVO {

    private static final long serialVersionUID = -2040071706447007612L;
    /**
     * 业务对象编码
     */
    private String code;
    /**
     * 业务对象名称
     */
    private String name;
    /**
     *  业务对象内容
     */
    private String content;
    /**
     * 业务对象所属实体主键Id
     */
    private Long entityId;
    /**
     * 业务对象所属工程主键Id
     */
    private Long projectId;

    private MdProjectVO project;
    private MdClassVO entity;
    
    /**
     * 二维码链接
     */
    private String qrcode;

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public Long getEntityId() {
        return entityId;
    }

    public void setEntityId(Long entityId) {
        this.entityId = entityId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public MdProjectVO getProject() {
        return project;
    }

    public void setProject(MdProjectVO project) {
        this.project = project;
    }

    public MdClassVO getEntity() {
        return entity;
    }

    public void setEntity(MdClassVO entity) {
        this.entity = entity;
    }

	public String getQrcode() {
		return qrcode;
	}

	public void setQrcode(String qrcode) {
		this.qrcode = qrcode;
	}
    
}
